package it.eng.urbanite.dashboard;

import java.time.Instant;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Component;

import it.eng.urbanite.dashboard.config.Constants;
import it.eng.urbanite.dashboard.model.enumeration.MenuType;
import it.eng.urbanite.dashboard.service.MenuBlockService;
import it.eng.urbanite.dashboard.service.dto.MenuBlockDTO;

@Component
public class Runner implements ApplicationRunner {
	private final Logger log = LoggerFactory.getLogger(Runner.class);

	@Autowired
	private MenuBlockService menuBlockService;

	@Override
	public void run(ApplicationArguments args) throws Exception {
		// TODO Auto-generated method stub
		if (hasRows()) {
			log.info("------------------ Start creating menu blocks ------------------");
			try {
				initPersonalMenuBlock();
				initSharedMenuBlock();
				initPublicMenuBlock();
			} catch (Throwable e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		log.info("------------------ Menu blocks created ------------------");
	}

	void initPersonalMenuBlock() {
		MenuBlockDTO menuBlockDTO = new MenuBlockDTO();
		menuBlockDTO.setCode("PRIVATE_DASHBOARDS");
		menuBlockDTO.setCreatedBy(Constants.SYSTEM);
		menuBlockDTO.setCreatedDate(Instant.now());
		menuBlockDTO.setIcon("lock-outline");
		menuBlockDTO.setLabel("Private");
		menuBlockDTO.setType(MenuType.PRIVATE);
		menuBlockService.save(menuBlockDTO);
	}

	void initSharedMenuBlock() {
		MenuBlockDTO menuBlockDTO = new MenuBlockDTO();
		menuBlockDTO.setCode("SHARED_DASHBOARDS");
		menuBlockDTO.setCreatedBy(Constants.SYSTEM);
		menuBlockDTO.setCreatedDate(Instant.now());
		menuBlockDTO.setIcon("share-outline");
		menuBlockDTO.setLabel("Shared");
		menuBlockDTO.setType(MenuType.SHARED);
		menuBlockService.save(menuBlockDTO);
	}

	void initPublicMenuBlock() {
		MenuBlockDTO menuBlockDTO = new MenuBlockDTO();
		menuBlockDTO.setCode("PUBLIC_DASHBOARDS");
		menuBlockDTO.setCreatedBy(Constants.SYSTEM);
		menuBlockDTO.setCreatedDate(Instant.now());
		menuBlockDTO.setIcon("globe-outline");
		menuBlockDTO.setLabel("Public");
		menuBlockDTO.setType(MenuType.PUBLIC);
		menuBlockService.save(menuBlockDTO);
	}

	boolean hasRows() {
		log.info("------------------ Checking if there are menu blocks ------------------");
		return menuBlockService.findAll().isEmpty() ? true : false;
	}
}