package it.eng.urbanite.dashboard.model;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import it.eng.urbanite.dashboard.model.enumeration.ComponentType;

/**
 * The DashboardComponent entity.
 */
@Entity
@Table(name = "dashboard_component")
public class DashboardComponent extends AbstractAuditingEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sequenceGenerator")
    @SequenceGenerator(name = "sequenceGenerator")
    private Long id;

    @NotNull
    @Enumerated(EnumType.STRING)
    @Column(name = "component_type", nullable = false)
    private ComponentType componentType;

    @NotNull
    @Column(name = "component_name", nullable = false)
    private String componentName;

    @Column(name = "componentcontent")
    private String componentcontent;

    @Column(name = "component_position")
    private String componentPosition;

    @ManyToOne
    @JsonIgnoreProperties(value = { "dashboardComponents", "targets" }, allowSetters = true)
    private DashboardPage dashboardPage;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public DashboardComponent id(Long id) {
        this.id = id;
        return this;
    }

    public ComponentType getComponentType() {
        return this.componentType;
    }

    public DashboardComponent componentType(ComponentType componentType) {
        this.componentType = componentType;
        return this;
    }

    public void setComponentType(ComponentType componentType) {
        this.componentType = componentType;
    }

    public String getComponentName() {
        return this.componentName;
    }

    public DashboardComponent componentName(String componentName) {
        this.componentName = componentName;
        return this;
    }

    public void setComponentName(String componentName) {
        this.componentName = componentName;
    }

    public String getComponentcontent() {
        return this.componentcontent;
    }

    public DashboardComponent componentcontent(String componentcontent) {
        this.componentcontent = componentcontent;
        return this;
    }

    public void setComponentcontent(String componentcontent) {
        this.componentcontent = componentcontent;
    }

    public String getComponentPosition() {
        return this.componentPosition;
    }

    public DashboardComponent componentPosition(String componentPosition) {
        this.componentPosition = componentPosition;
        return this;
    }

    public void setComponentPosition(String componentPosition) {
        this.componentPosition = componentPosition;
    }

    public DashboardPage getDashboardPage() {
        return this.dashboardPage;
    }

    public DashboardComponent dashboardPage(DashboardPage dashboardPage) {
        this.setDashboardPage(dashboardPage);
        return this;
    }

    public void setDashboardPage(DashboardPage dashboardPage) {
        this.dashboardPage = dashboardPage;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof DashboardComponent)) {
            return false;
        }
        return id != null && id.equals(((DashboardComponent) o).id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public String toString() {
        return "DashboardComponent{" +
            "id=" + getId() +
            ", componentType='" + getComponentType() + "'" +
            ", componentName='" + getComponentName() + "'" +
            ", componentcontent='" + getComponentcontent() + "'" +
            ", componentPosition='" + getComponentPosition() + "'" +
            "}";
    }
}
