package it.eng.urbanite.dashboard.model;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import it.eng.urbanite.dashboard.model.enumeration.MenuType;

/**
 * The DashboardPage entity.
 */
@Entity
@Table(name = "dashboard_page")
public class DashboardPage extends AbstractAuditingEntity implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sequenceGenerator")
    @SequenceGenerator(name = "sequenceGenerator")
    private Long id;

    @NotNull
    @Column(name = "name", nullable = false)
    private String name;

    @Column(name = "description")
    private String description;

    @Lob
    @Column(name = "content")
    //@Column(name = "content", length = 65000)
    //@NotNull
    private String content;

    @Column(name = "note")
    private String note;

    @Column(name = "shared")
    private Boolean shared;
    
    @Column(name = "type")
    private MenuType type;

    @OneToMany(mappedBy = "dashboardPage")
    @JsonIgnoreProperties(value = { "dashboardPage" }, allowSetters = true)
    private Set<DashboardComponent> dashboardComponents = new HashSet<>();

    @OneToMany(mappedBy = "dashboardPage")
    @JsonIgnoreProperties(value = { "dashboardPage" }, allowSetters = true)
    private Set<Target> targets = new HashSet<>();

    
    public DashboardPage type(MenuType type) {
        this.type = type;
        return this;
    }
    
    public MenuType getType() {
		return type;
	}

	public void setType(MenuType type) {
		this.type = type;
	}

	public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public DashboardPage id(Long id) {
        this.id = id;
        return this;
    }

    public String getName() {
        return this.name;
    }

    public DashboardPage name(String name) {
        this.name = name;
        return this;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return this.description;
    }

    public DashboardPage description(String description) {
        this.description = description;
        return this;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getContent() {
        return this.content;
    }

    public DashboardPage content(String content) {
        this.content = content;
        return this;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getNote() {
        return this.note;
    }

    public DashboardPage note(String note) {
        this.note = note;
        return this;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public Boolean getShared() {
        return this.shared;
    }

    public DashboardPage shared(Boolean shared) {
        this.shared = shared;
        return this;
    }

    public void setShared(Boolean shared) {
        this.shared = shared;
    }

    public Set<DashboardComponent> getDashboardComponents() {
        return this.dashboardComponents;
    }

    public DashboardPage dashboardComponents(Set<DashboardComponent> dashboardComponents) {
        this.setDashboardComponents(dashboardComponents);
        return this;
    }

    public DashboardPage addDashboardComponent(DashboardComponent dashboardComponent) {
        this.dashboardComponents.add(dashboardComponent);
        dashboardComponent.setDashboardPage(this);
        return this;
    }

    public DashboardPage removeDashboardComponent(DashboardComponent dashboardComponent) {
        this.dashboardComponents.remove(dashboardComponent);
        dashboardComponent.setDashboardPage(null);
        return this;
    }

    public void setDashboardComponents(Set<DashboardComponent> dashboardComponents) {
        if (this.dashboardComponents != null) {
            this.dashboardComponents.forEach(i -> i.setDashboardPage(null));
        }
        if (dashboardComponents != null) {
            dashboardComponents.forEach(i -> i.setDashboardPage(this));
        }
        this.dashboardComponents = dashboardComponents;
    }

    public Set<Target> getTargets() {
        return this.targets;
    }

    public DashboardPage targets(Set<Target> targets) {
        this.setTargets(targets);
        return this;
    }

    public DashboardPage addTarget(Target target) {
        this.targets.add(target);
        target.setDashboardPage(this);
        return this;
    }

    public DashboardPage removeTarget(Target target) {
        this.targets.remove(target);
        target.setDashboardPage(null);
        return this;
    }

    public void setTargets(Set<Target> targets) {
        if (this.targets != null) {
            this.targets.forEach(i -> i.setDashboardPage(null));
        }
        if (targets != null) {
            targets.forEach(i -> i.setDashboardPage(this));
        }
        this.targets = targets;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof DashboardPage)) {
            return false;
        }
        return id != null && id.equals(((DashboardPage) o).id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public String toString() {
        return "DashboardPage{" +
            "id=" + getId() +
            ", name='" + getName() + "'" +
            ", description='" + getDescription() + "'" +
            ", content='" + getContent() + "'" +
            ", note='" + getNote() + "'" +
            ", shared='" + getShared() + "'" +
            "}";
    }
}
