package it.eng.urbanite.dashboard.model;

import java.io.Serializable;
import java.time.Instant;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import it.eng.urbanite.dashboard.model.enumeration.MenuType;

/**
 * The MenuBlock entity.
 */
@Entity
@Table(name = "menu_block")
public class MenuBlock implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sequenceGenerator")
    @SequenceGenerator(name = "sequenceGenerator")
    private Long id;

    @NotNull
    @Column(name = "code", nullable = false)
    private String code;

    @NotNull
    @Column(name = "label", nullable = false)
    private String label;

    @Column(name = "jhi_order")
    private Integer order;

    @NotNull
    @Enumerated(EnumType.STRING)
    @Column(name = "type", nullable = false)
    private MenuType type;

    @Column(name = "icon")
    private String icon;
    
    @Column(name = "created_date")
    private Instant createdDate;

    @Column(name = "created_by")
    private String createdBy;

    @OneToMany(mappedBy = "menuBlock")
    @JsonIgnoreProperties(value = { "dashboardPage", "menuBlock" }, allowSetters = true)
    private Set<MenuItem> menuItems = new HashSet<>();
    
    
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public MenuBlock id(Long id) {
        this.id = id;
        return this;
    }

    public String getCode() {
        return this.code;
    }

    public MenuBlock code(String code) {
        this.code = code;
        return this;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getLabel() {
        return this.label;
    }

    public MenuBlock label(String label) {
        this.label = label;
        return this;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getOrder() {
        return this.order;
    }

    public MenuBlock order(Integer order) {
        this.order = order;
        return this;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }

    public MenuType getType() {
        return this.type;
    }

    public MenuBlock type(MenuType type) {
        this.type = type;
        return this;
    }

    public void setType(MenuType type) {
        this.type = type;
    }

    public Instant getCreatedDate() {
        return this.createdDate;
    }

    public MenuBlock createdDate(Instant createdDate) {
        this.createdDate = createdDate;
        return this;
    }

    public void setCreatedDate(Instant createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreatedBy() {
        return this.createdBy;
    }

    public MenuBlock createdBy(String createdBy) {
        this.createdBy = createdBy;
        return this;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public Set<MenuItem> getMenuItems() {
        return this.menuItems;
    }

    public MenuBlock menuItems(Set<MenuItem> menuItems) {
        this.setMenuItems(menuItems);
        return this;
    }

    public MenuBlock addMenuItem(MenuItem menuItem) {
        this.menuItems.add(menuItem);
        menuItem.setMenuBlock(this);
        return this;
    }

    public MenuBlock removeMenuItem(MenuItem menuItem) {
        this.menuItems.remove(menuItem);
        menuItem.setMenuBlock(null);
        return this;
    }

    public void setMenuItems(Set<MenuItem> menuItems) {
        if (this.menuItems != null) {
            this.menuItems.forEach(i -> i.setMenuBlock(null));
        }
        if (menuItems != null) {
            menuItems.forEach(i -> i.setMenuBlock(this));
        }
        this.menuItems = menuItems;
    }

    public String getIcon() {
		return icon;
	}

    public MenuBlock icon(String icon) {
        this.icon = icon;
        return this;
    }
    
	public void setIcon(String icon) {
		this.icon = icon;
	}

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof MenuBlock)) {
            return false;
        }
        return id != null && id.equals(((MenuBlock) o).id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public String toString() {
        return "MenuBlock{" +
            "id=" + getId() +
            ", code='" + getCode() + "'" +
            ", label='" + getLabel() + "'" +
            ", order=" + getOrder() +
            ", icon=" + getIcon() +
            ", type='" + getType() + "'" +
            ", createdDate='" + getCreatedDate() + "'" +
            ", createdBy='" + getCreatedBy() + "'" +
            "}";
    }
    
}
