package it.eng.urbanite.dashboard.model;

import java.io.Serializable;
import java.time.Instant;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import it.eng.urbanite.dashboard.model.enumeration.MenuType;

/**
 * The MenuItem entity.
 */
@Entity
@Table(name = "menu_item")
public class MenuItem implements Serializable {
    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "sequenceGenerator")
    @SequenceGenerator(name = "sequenceGenerator")
    private Long id;

    @NotNull
    @Column(name = "code", nullable = false)
    private String code;

    @NotNull
    @Column(name = "label", nullable = false)
    private String label;

    @Column(name = "jhi_order")
    private Integer order;

    @NotNull
    @Enumerated(EnumType.STRING)
    @Column(name = "type", nullable = false)
    private MenuType type;

    @Column(name = "created_date")
    private Instant createdDate;

    @Column(name = "created_by")
    private String createdBy;

    @Column(name = "icon")
    private String icon;
    
    @JsonIgnoreProperties(value = { "dashboardComponents", "menuItem", "targets" }, allowSetters = true)
    @OneToOne
    @JoinColumn(unique = true)
    private DashboardPage dashboardPage;

    @ManyToOne
    @JsonIgnoreProperties(value = { "menuItems" }, allowSetters = true)
    private MenuBlock menuBlock;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public MenuItem id(Long id) {
        this.id = id;
        return this;
    }

    public String getCode() {
        return this.code;
    }

    public MenuItem code(String code) {
        this.code = code;
        return this;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getLabel() {
        return this.label;
    }

    public MenuItem label(String label) {
        this.label = label;
        return this;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getOrder() {
        return this.order;
    }

    public MenuItem order(Integer order) {
        this.order = order;
        return this;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }

    public MenuType getType() {
        return this.type;
    }

    public MenuItem type(MenuType type) {
        this.type = type;
        return this;
    }

    public void setType(MenuType type) {
        this.type = type;
    }

    public Instant getCreatedDate() {
        return this.createdDate;
    }

    public MenuItem createdDate(Instant createdDate) {
        this.createdDate = createdDate;
        return this;
    }

    public void setCreatedDate(Instant createdDate) {
        this.createdDate = createdDate;
    }

    public String getCreatedBy() {
        return this.createdBy;
    }

    public MenuItem createdBy(String createdBy) {
        this.createdBy = createdBy;
        return this;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public DashboardPage getDashboardPage() {
        return this.dashboardPage;
    }

    public MenuItem dashboardPage(DashboardPage dashboardPage) {
        this.setDashboardPage(dashboardPage);
        return this;
    }

    public void setDashboardPage(DashboardPage dashboardPage) {
        this.dashboardPage = dashboardPage;
    }

    public MenuBlock getMenuBlock() {
        return this.menuBlock;
    }

    public MenuItem menuBlock(MenuBlock menuBlock) {
        this.setMenuBlock(menuBlock);
        return this;
    }

    public void setMenuBlock(MenuBlock menuBlock) {
        this.menuBlock = menuBlock;
    }

    public String getIcon() {
		return icon;
	}

    public MenuItem icon(String icon) {
        this.icon = icon;
        return this;
    }
    
	public void setIcon(String icon) {
		this.icon = icon;
	}

	@Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof MenuItem)) {
            return false;
        }
        return id != null && id.equals(((MenuItem) o).id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }

    @Override
    public String toString() {
        return "MenuItem{" +
            "id=" + getId() +
            ", code='" + getCode() + "'" +
            ", label='" + getLabel() + "'" +
            ", order=" + getOrder() +
            ", icon=" + getIcon() +
            ", type='" + getType() + "'" +
            ", createdDate='" + getCreatedDate() + "'" +
            ", createdBy='" + getCreatedBy() + "'" +
            "}";
    }
}
