package it.eng.urbanite.dashboard.repository;

import java.util.List;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import it.eng.urbanite.dashboard.model.DashboardPage;

/**
 * Spring Data SQL repository for the DashboardPage entity.
 */
@Repository
public interface DashboardPageRepository extends JpaRepository<DashboardPage, Long>, JpaSpecificationExecutor<DashboardPage> {
	
    @Query(value = "select distinct dashboardPage from DashboardPage dashboardPage "
    		+ "left join fetch dashboardPage.targets targets "
    		+ "where dashboardPage.shared=:shared "
			+ "and dashboardPage.id in (select menuItem.dashboardPage.id from MenuItem menuItem where menuItem.type='SHARED' and menuItem.dashboardPage.id = dashboardPage.id) "
    		+ "and ( "
    		+ "        dashboardPage.createdBy=:createdBy or "
    		+ "        ( targets.type='ROLE' and targets.name in (:roles) )  or "
    		+ "        ( targets.type='GROUP' and targets.name in (:groups) )  or "
    		+ "        ( targets.type='PERSON' and targets.name=:createdBy)  "
    		+ ") ")
    List<DashboardPage> findAllPagesShared(	@Param("createdBy") String createdBy, 
    										@Param("shared") Boolean shared, 
    										@Param("roles") List<String> roles, 
    										@Param("groups") List<String> groups);
    
    
    
    @Query(value = "select distinct dashboardPage from DashboardPage dashboardPage "
    		+ "left join fetch dashboardPage.targets targets "
    		+ "where dashboardPage.createdBy=:createdBy "
			+ "and dashboardPage.id in (select menuItem.dashboardPage.id from MenuItem menuItem where menuItem.type='PERSONAL' and menuItem.dashboardPage.id = dashboardPage.id) " )
    List<DashboardPage> findAllPagesPersonal(@Param("createdBy") String createdBy);
    
    
}
