package it.eng.urbanite.dashboard.repository;

import java.util.List;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import it.eng.urbanite.dashboard.model.DashboardPage;
import it.eng.urbanite.dashboard.model.MenuBlock;
import it.eng.urbanite.dashboard.model.MenuItem;
import it.eng.urbanite.dashboard.model.enumeration.MenuType;

/**
 * Spring Data SQL repository for the MenuBlock entity.
 */
@SuppressWarnings("unused")
@Repository
public interface MenuBlockRepository extends JpaRepository<MenuBlock, Long>, JpaSpecificationExecutor<MenuBlock> {

	/**
	 * @param type MenuType
	 * @return List of MenuBlock
	 */
	List<MenuBlock> findByType(MenuType type);
	
	/**
	 * @param type MenuType
	 * @param createdBy String
	 * @return List of MenuBlock
	 */
	List<MenuBlock> findByTypeAndCreatedBy(MenuType type, String createdBy);
	
	
	/**
	 * Return MenuBlocks (if shared with targets following the query below)
	 * 
		SELECT distinct i.menu_block_id FROM menu_item i
		LEFT JOIN menu_block m ON i.menu_block_id = m.id
		LEFT JOIN dashboard_page p ON i.dashboard_page_id = p.id
		LEFT JOIN target t ON t.dashboard_page_id = p.id
		WHERE p.shared = true AND m.type = 'SHARED' AND i.type = m.type
		AND ( p.created_by='user' or
			  (t.type='PERSON' and t.name='user') or
			  (t.type='ROLE' and t.name in ('TRAFFIC') ) 
			  (t.type='GROUP' and t.name in ('G2') )
		);
	 *
	 * @param createdBy
	 * @param shared
	 * @param roles
	 * @param groups
	 * @return List of MenuBlock
	 */
    @Query(nativeQuery=true, value=
    		  "SELECT * from menu_block r where r.id in ( "
    		+ "SELECT distinct i.menu_block_id FROM menu_item i "
    		+ "LEFT JOIN menu_block m ON i.menu_block_id = m.id "
    		+ "LEFT JOIN dashboard_page p ON i.dashboard_page_id = p.id "
    		+ "LEFT JOIN target t ON t.dashboard_page_id = p.id "
    		+ "WHERE p.shared = :shared "
    		+ "AND m.type = :type "
    		+ "AND i.type = m.type "
    		+ "AND ( "
    		+ "    p.created_by= :createdBy or "
    		+ "    (t.type='ROLE' and t.name in (:roles))  or "
    		+ "    (t.type='GROUP' and t.name in (:groups)) or"
    		+ "    (t.type='PERSON' and t.name=:createdBy)  "
    		+ ") )")
    List<MenuBlock> findBlocks( @Param("createdBy") String createdBy, 
								@Param("shared") Boolean shared, 
								@Param("type") String type ,
								@Param("roles") List<String> roles,
								@Param("groups") List<String> groups );
    
    
	/**
	 * Return EDITABLE MenuBlocks: (SHARED) or (PERSONAL and created-by user)
	 * 
	 * @param createdBy
	 * @return List of MenuBlock
	 */
    @Query(nativeQuery=true, value= "SELECT * from menu_block m where 1=1 and ( (m.created_by = :createdBy and m.type='PERSONAL') or m.type='SHARED' or m.type='PUBLIC' ) " )
    List<MenuBlock> findEditable( @Param("createdBy") String createdBy );
    
	   
}
