package it.eng.urbanite.dashboard.repository;

import java.util.List;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import it.eng.urbanite.dashboard.model.DashboardPage;
import it.eng.urbanite.dashboard.model.MenuItem;
import it.eng.urbanite.dashboard.model.enumeration.MenuType;

/**
 * Spring Data SQL repository for the MenuItem entity.
 */
@SuppressWarnings("unused")
@Repository
public interface MenuItemRepository extends JpaRepository<MenuItem, Long>, JpaSpecificationExecutor<MenuItem> {
	
	/**
	 * @param type MenuType
	 * @return List of MenuItem
	 */
	List<MenuItem> findByType(MenuType type);

	/**
	 * @param dashboardPage DashboardPage
	 * @return List of MenuItem
	 */
	List<MenuItem> findByDashboardPage(DashboardPage dashboardPage);
	
	/**
	 * @param dashboardPageId DashboardPage ID
	 * @return List of MenuItem
	 */
	List<MenuItem> findByDashboardPageId(Long dashboardPageId);
	
	/**
	 * @param type MenuType
	 * @param createdBy String
	 * @return List of MenuItem
	 */
	List<MenuItem> findByTypeAndCreatedBy(MenuType type, String createdBy);
	
    /**
     * Return MenuItems (if shared with targets following the query below)
     * 
		SELECT distinct i.id FROM menu_item i
		LEFT JOIN menu_block m ON i.menu_block_id = m.id
		LEFT JOIN dashboard_page p ON i.dashboard_page_id = p.id
		LEFT JOIN target t ON t.dashboard_page_id = p.id
		WHERE p.shared = true AND m.type = 'SHARED' AND i.type = m.type
		AND ( p.created_by='user' or
			  (t.type='PERSON' and t.name='user') or
			  (t.type='ROLE' and t.name in ('TRAFFIC') )  or
			  (t.type='GROUP' and t.name in ('G2') )
		);
     *
     * @param createdBy
     * @param shared
     * @param roles
     * @param groups
     * @return List of MenuItem
     */
    @Query(nativeQuery=true, value=
    		"SELECT * from menu_item r where r.id in ( "
    				+ "SELECT distinct i.id FROM menu_item i "
    				+ "LEFT JOIN menu_block m ON i.menu_block_id = m.id "
    				+ "LEFT JOIN dashboard_page p ON i.dashboard_page_id = p.id "
    				+ "LEFT JOIN target t ON t.dashboard_page_id = p.id "
    				+ "WHERE p.shared = :shared "
    				+ "AND m.type = :type "
    				+ "AND i.type = m.type "
    				+ "AND ( "
    				+ "    p.created_by= :createdBy or "
    				+ "    (t.type='ROLE' and t.name in (:roles))  or "
    				+ "    (t.type='GROUP' and t.name in (:groups)) or"
    				+ "    (t.type='PERSON' and t.name=:createdBy)  "
    				+ ") )")
    List<MenuItem> findMenuItems( 	@Param("createdBy") String createdBy, 
						    		@Param("shared") Boolean shared, 
						    		@Param("type") String type ,
						    		@Param("roles") List<String> roles,
						    		@Param("groups") List<String> groups );
}
