package it.eng.urbanite.dashboard.security;

import org.keycloak.adapters.KeycloakConfigResolver;
import org.keycloak.adapters.springboot.KeycloakSpringBootConfigResolver;
import org.keycloak.adapters.springsecurity.KeycloakConfiguration;
import org.keycloak.adapters.springsecurity.authentication.KeycloakAuthenticationProvider;
import org.keycloak.adapters.springsecurity.client.KeycloakClientRequestFactory;
import org.keycloak.adapters.springsecurity.client.KeycloakRestTemplate;
import org.keycloak.adapters.springsecurity.config.KeycloakWebSecurityConfigurerAdapter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Scope;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.core.authority.mapping.SimpleAuthorityMapper;
import org.springframework.security.web.authentication.session.NullAuthenticatedSessionStrategy;
import org.springframework.security.web.authentication.session.SessionAuthenticationStrategy;

@KeycloakConfiguration
public class SecurityConfig extends KeycloakWebSecurityConfigurerAdapter {

	@Autowired
	public void configureGlobal(AuthenticationManagerBuilder auth) throws Exception {
		KeycloakAuthenticationProvider keycloakAuthenticationProvider = keycloakAuthenticationProvider();
		keycloakAuthenticationProvider.setGrantedAuthoritiesMapper(new SimpleAuthorityMapper());
		auth.authenticationProvider(keycloakAuthenticationProvider);
	}

	@Bean
	@Override
	protected SessionAuthenticationStrategy sessionAuthenticationStrategy() {
		return new NullAuthenticatedSessionStrategy();
	}
	
	@Bean
	public KeycloakConfigResolver keycloakConfigResolver(){
		return new KeycloakSpringBootConfigResolver();
	}

	@Autowired
	public KeycloakClientRequestFactory keycloakClientRequestFactory;

	@Bean
	@Scope(ConfigurableBeanFactory.SCOPE_PROTOTYPE)
	public KeycloakRestTemplate keycloakRestTemplate(){
		return new KeycloakRestTemplate(keycloakClientRequestFactory);
	}
	
	
	@Override
	protected void configure(HttpSecurity http) throws Exception{
		super.configure(http);
		http.cors().and()
        .anonymous().and().csrf().disable().authorizeRequests()
        .antMatchers("/api/menu-blocks").permitAll()
			.antMatchers("/api/**").hasAnyAuthority("ROLE_USER", "ROLE_ADMIN")
			.antMatchers("/user/**").hasAnyAuthority("ROLE_USER", "ROLE_ADMIN")
			.antMatchers("/app/info").permitAll()
	        .antMatchers("/public/public-menu-blocks").permitAll()

			.anyRequest().permitAll() // giving access to e.g. swagger
	        .and().httpBasic(); // Authenticate users with HTTP basic authentication
	}

//	@Override
//	protected void configure(HttpSecurity http) throws Exception{
//		super.configure(http);
//		http.authorizeRequests()
////				.antMatchers("/api/**").hasAnyAuthority("ROLE_USER", "ROLE_ADMIN") //TODO Manage dynamically Authorities
////				//.hasRole("USER")
////				.antMatchers("/user/**").hasAnyAuthority("ROLE_USER", "ROLE_ADMIN")
////				.antMatchers("/app/info").permitAll()
//				
//				.anyRequest().permitAll() // giving access to e.g. swagger
//				
//		.and().csrf().disable();
//	}	

}