package it.eng.urbanite.dashboard.service;

import java.util.List;
import java.util.Optional;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import it.eng.urbanite.dashboard.model.enumeration.CloningOpionType;
import it.eng.urbanite.dashboard.service.dto.DashboardPageDTO;

/**
 * Service Interface for managing {@link it.eng.urbanite.dashboard.domain.DashboardPage}.
 */
public interface DashboardPageService {
    /**
     * Save a dashboardPage.
     *
     * @param dashboardPageDTO the entity to save.
     * @return the persisted entity.
     */
    DashboardPageDTO save(DashboardPageDTO dashboardPageDTO);

    /**
     * Get all the dashboardPages.
     *
     * @param pageable the pagination information.
     * @return the list of entities.
     */
    Page<DashboardPageDTO> findAll(Pageable pageable);

    /**
     * Get all the dashboardPages.
     *
     * @return the list of entities.
     */
    List<DashboardPageDTO> findAll();
    
    /**
     * Get all the shared dashboardPages (i.e. linked to a menuItem with type SHARED)
     * 
     * @param createdBy
     * @param shared
     * @param roles
     * @param groups
     * @return the list of entities.
     */
    List<DashboardPageDTO> findAllPagesShared(String createdBy, Boolean shared, List<String> roles, List<String> groups);
    
    
    /**
     * Get all the personal dashboardPages (i.e. linked to a menuItem with type PERSONAL)
     * 
     * @param createdBy
     * @return the list of entities.
     */
    List<DashboardPageDTO> findAllPagesPersonal(String createdBy);
    
    
    /**
     * Get the "id" dashboardPage.
     *
     * @param id the id of the entity.
     * @return the entity.
     */
    Optional<DashboardPageDTO> findOne(Long id);

    /**
     * Delete the "id" dashboardPage.
     *
     * @param id the id of the entity.
     */
    void delete(Long id);
    
    /**
     * Delete the "id" dashboardPage.
     *
     * @param id the id of the entity.
     */
    void deepDelete(Long id);
    
    /**
     * Duplicate the "id" dashboardPage.
     *
     * @param id the id of the entity.
     * @param createdBy the createdBy.
     * @param dashboardName the dashboardName.
     * @param option the CloningOpionType.
     * @return duplicated entity.
     */
    DashboardPageDTO duplicatePage(Long id, String createdBy, String dashboardName, CloningOpionType option);
    
    
}
