package it.eng.urbanite.dashboard.service;

import java.util.List;
import java.util.Optional;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import it.eng.urbanite.dashboard.model.enumeration.MenuType;
import it.eng.urbanite.dashboard.service.dto.MenuBlockDTO;

/**
 * Service Interface for managing {@link it.eng.urbanite.dashboard.domain.MenuBlock}.
 */
public interface MenuBlockService {
    /**
     * Save a menuBlock.
     *
     * @param menuBlockDTO the entity to save.
     * @return the persisted entity.
     */
    MenuBlockDTO save(MenuBlockDTO menuBlockDTO);

    /**
     * Get all the menuBlocks.
     *
     * @param pageable the pagination information.
     * @return the list of entities.
     */
    Page<MenuBlockDTO> findAll(Pageable pageable);

    /**
     * Get all the menuBlocks.
     *
     * @return the list of entities.
     */
    List<MenuBlockDTO> findAll();
    
    
    /**
     * Find all MenuBlockDTO Completed with liked Items (For UI)
     * 
     * @param type
     * @param createdBy
     * @return the list of entities.
     */
	List<MenuBlockDTO> findLinkedItems(MenuType type, String createdBy);
	
	
	/**
     * Find all Editable MenuBlockDTO (for select in UI)
     * 
     * @return the list of entities.
     */
	List<MenuBlockDTO> findEditableBlocks();
	
	
    /**
     * Get the "id" menuBlock.
     *
     * @param id the id of the entity.
     * @return the entity.
     */
    Optional<MenuBlockDTO> findOne(Long id);

    /**
     * Delete the "id" menuBlock.
     *
     * @param id the id of the entity.
     */
    void delete(Long id);
}
