package it.eng.urbanite.dashboard.service;

import java.util.List;
import java.util.Optional;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import it.eng.urbanite.dashboard.service.dto.MenuItemDTO;

/**
 * Service Interface for managing {@link it.eng.urbanite.dashboard.domain.MenuItem}.
 */
public interface MenuItemService {
    /**
     * Save a menuItem.
     *
     * @param menuItemDTO the entity to save.
     * @return the persisted entity.
     */
    MenuItemDTO save(MenuItemDTO menuItemDTO);

    /**
     * Get all the menuItems.
     *
     * @param pageable the pagination information.
     * @return the list of entities.
     */
    Page<MenuItemDTO> findAll(Pageable pageable);

    /**
     * Get all the menuItems.
     *
     * @return the list of entities.
     */
    List<MenuItemDTO> findAll();

    /**
     * Get the "id" menuItem.
     *
     * @param id the id of the entity.
     * @return the entity.
     */
    Optional<MenuItemDTO> findOne(Long id);

    /**
     * Delete the "id" menuItem.
     *
     * @param id the id of the entity.
     */
    void delete(Long id);
}
