package it.eng.urbanite.dashboard.service;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import it.eng.urbanite.dashboard.model.TargetAvailable;
import it.eng.urbanite.dashboard.model.TargetAvailable_;
import it.eng.urbanite.dashboard.repository.TargetAvailableRepository;
import it.eng.urbanite.dashboard.service.criteria.TargetAvailableCriteria;
import it.eng.urbanite.dashboard.service.dto.TargetAvailableDTO;
import it.eng.urbanite.dashboard.service.mapper.TargetAvailableMapper;
import tech.jhipster.service.QueryService;

@Service
@Transactional(readOnly = true)
public class TargetAvailableQueryService extends QueryService<TargetAvailable> {
    private final Logger log = LoggerFactory.getLogger(TargetAvailableQueryService.class);
    private final TargetAvailableRepository repository;
    private final TargetAvailableMapper mapper;
	
    public TargetAvailableQueryService(TargetAvailableRepository repository, TargetAvailableMapper  mapper) {
        this.repository = repository;
        this. mapper =  mapper;
    }

    @Transactional(readOnly = true)
    public List<TargetAvailableDTO> findByCriteria(TargetAvailableCriteria criteria) {
        log.debug("find by criteria : {}", criteria);
        final Specification<TargetAvailable> specification = createSpecification(criteria);
        return  mapper.toDto(repository.findAll(specification));
    }

    @Transactional(readOnly = true)
    public Page<TargetAvailableDTO> findByCriteria(TargetAvailableCriteria criteria, Pageable page) {
        log.debug("find by criteria : {}, page: {}", criteria, page);
        final Specification<TargetAvailable> specification = createSpecification(criteria);
        return repository.findAll(specification, page).map( mapper::toDto);
    }

    @Transactional(readOnly = true)
    public long countByCriteria(TargetAvailableCriteria criteria) {
        log.debug("count by criteria : {}", criteria);
        final Specification<TargetAvailable> specification = createSpecification(criteria);
        return repository.count(specification);
    }

    protected Specification<TargetAvailable> createSpecification(TargetAvailableCriteria criteria) {
        Specification<TargetAvailable> specification = Specification.where(null);
        if (criteria != null) {
            if (criteria.getId() != null) {
                specification = specification.and(buildRangeSpecification(criteria.getId(), TargetAvailable_.id));
            }
            if (criteria.getType() != null) {
                specification = specification.and(buildSpecification(criteria.getType(), TargetAvailable_.type));
            }
            if (criteria.getCode() != null) {
                specification = specification.and(buildStringSpecification(criteria.getCode(), TargetAvailable_.code));
            }
            if (criteria.getValue() != null) {
                specification = specification.and(buildStringSpecification(criteria.getValue(), TargetAvailable_.value));
            }
            if (criteria.getCreatedDate() != null) {
                specification = specification.and(buildRangeSpecification(criteria.getCreatedDate(), TargetAvailable_.createdDate));
            }
            if (criteria.getCreatedBy() != null) {
                specification = specification.and(buildStringSpecification(criteria.getCreatedBy(), TargetAvailable_.createdBy));
            }
        }
        return specification;
    }
}
