package it.eng.urbanite.dashboard.service;

import java.util.List;
import java.util.Optional;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import it.eng.urbanite.dashboard.service.dto.TargetDTO;

/**
 * Service Interface for managing {@link it.eng.urbanite.dashboard.domain.Target}.
 */
public interface TargetService {
    /**
     * Save a target.
     *
     * @param targetDTO the entity to save.
     * @return the persisted entity.
     */
    TargetDTO save(TargetDTO targetDTO);

    /**
     * Get all the targets.
     *
     * @param pageable the pagination information.
     * @return the list of entities.
     */
    Page<TargetDTO> findAll(Pageable pageable);

    /**
     * Get all the targets.
     *
     * @return the list of entities.
     */
    List<TargetDTO> findAll();

    /**
     * Get the "id" target.
     *
     * @param id the id of the entity.
     * @return the entity.
     */
    Optional<TargetDTO> findOne(Long id);

    /**
     * Delete the "id" target.
     *
     * @param id the id of the entity.
     */
    void delete(Long id);
}
