package it.eng.urbanite.dashboard.service;

import java.util.HashMap;
import java.util.List;
import org.keycloak.representations.idm.GroupRepresentation;
import org.keycloak.representations.idm.RoleRepresentation;
import org.keycloak.representations.idm.UserRepresentation;

import it.eng.urbanite.dashboard.service.dto.UserDTO;

/**
 * Service Interface for managing User coming from IDM
 */
public interface UserService {

	/**
	 * Get all the users from IDM Keycloak.
	 * @return the list of entities.
	 */
	List<UserDTO> findAllUsers();

	/**
	 * Get all the roles from IDM Keycloak.
	 * @return the list of entities.
	 */
	List<RoleRepresentation> findAllRoles();

	/**
	 * Get all the groups from IDM Keycloak.
	 * @return the list of entities.
	 */
	List<GroupRepresentation> findAllGroups();


	/**
	 * Get all the user/groups from IDM Keycloak.
	 * @param  username username
	 * See https://github.com/keycloak/keycloak/blob/master/testsuite/integration-arquillian/tests/base/src/test/java/org/keycloak/testsuite/admin/group/GroupTest.java
	 * @return the map of entities (key: groupName, value: List of Users related to this group) 
	 */
	HashMap<String, List<UserRepresentation>> findGroupsFromUser(String username);

}
