package it.eng.urbanite.dashboard.service.criteria;

import java.io.Serializable;
import java.util.Objects;

import it.eng.urbanite.dashboard.model.enumeration.MenuType;
import tech.jhipster.service.Criteria;
import tech.jhipster.service.filter.Filter;
import tech.jhipster.service.filter.InstantFilter;
import tech.jhipster.service.filter.IntegerFilter;
import tech.jhipster.service.filter.LongFilter;
import tech.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link it.eng.urbanite.dashboard.domain.MenuItem} entity. This class is used
 * in {@link it.eng.urbanite.dashboard.web.rest.MenuItemResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /menu-items?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
public class MenuItemCriteria implements Serializable, Criteria {

    /**
     * Class for filtering MenuType
     */
    public static class MenuTypeFilter extends Filter<MenuType> {


		/**
		 * 
		 */
		private static final long serialVersionUID = 1549527396273610049L;

		public MenuTypeFilter() {}

        public MenuTypeFilter(MenuTypeFilter filter) {
            super(filter);
        }

        @Override
        public MenuTypeFilter copy() {
            return new MenuTypeFilter(this);
        }
    }

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private StringFilter code;

    private StringFilter label;

    private IntegerFilter order;

    private MenuTypeFilter type;

    private InstantFilter createdDate;

    private StringFilter createdBy;

    private LongFilter dashboardPageId;

    private LongFilter menuBlockId;

    public MenuItemCriteria() {}

    public MenuItemCriteria(MenuItemCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.code = other.code == null ? null : other.code.copy();
        this.label = other.label == null ? null : other.label.copy();
        this.order = other.order == null ? null : other.order.copy();
        this.type = other.type == null ? null : other.type.copy();
        this.createdDate = other.createdDate == null ? null : other.createdDate.copy();
        this.createdBy = other.createdBy == null ? null : other.createdBy.copy();
        this.dashboardPageId = other.dashboardPageId == null ? null : other.dashboardPageId.copy();
        this.menuBlockId = other.menuBlockId == null ? null : other.menuBlockId.copy();
    }

    @Override
    public MenuItemCriteria copy() {
        return new MenuItemCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public LongFilter id() {
        if (id == null) {
            id = new LongFilter();
        }
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public StringFilter getCode() {
        return code;
    }

    public StringFilter code() {
        if (code == null) {
            code = new StringFilter();
        }
        return code;
    }

    public void setCode(StringFilter code) {
        this.code = code;
    }

    public StringFilter getLabel() {
        return label;
    }

    public StringFilter label() {
        if (label == null) {
            label = new StringFilter();
        }
        return label;
    }

    public void setLabel(StringFilter label) {
        this.label = label;
    }

    public IntegerFilter getOrder() {
        return order;
    }

    public IntegerFilter order() {
        if (order == null) {
            order = new IntegerFilter();
        }
        return order;
    }

    public void setOrder(IntegerFilter order) {
        this.order = order;
    }

    public MenuTypeFilter getType() {
        return type;
    }

    public MenuTypeFilter type() {
        if (type == null) {
            type = new MenuTypeFilter();
        }
        return type;
    }

    public void setType(MenuTypeFilter type) {
        this.type = type;
    }

    public InstantFilter getCreatedDate() {
        return createdDate;
    }

    public InstantFilter createdDate() {
        if (createdDate == null) {
            createdDate = new InstantFilter();
        }
        return createdDate;
    }

    public void setCreatedDate(InstantFilter createdDate) {
        this.createdDate = createdDate;
    }

    public StringFilter getCreatedBy() {
        return createdBy;
    }

    public StringFilter createdBy() {
        if (createdBy == null) {
            createdBy = new StringFilter();
        }
        return createdBy;
    }

    public void setCreatedBy(StringFilter createdBy) {
        this.createdBy = createdBy;
    }

    public LongFilter getDashboardPageId() {
        return dashboardPageId;
    }

    public LongFilter dashboardPageId() {
        if (dashboardPageId == null) {
            dashboardPageId = new LongFilter();
        }
        return dashboardPageId;
    }

    public void setDashboardPageId(LongFilter dashboardPageId) {
        this.dashboardPageId = dashboardPageId;
    }

    public LongFilter getMenuBlockId() {
        return menuBlockId;
    }

    public LongFilter menuBlockId() {
        if (menuBlockId == null) {
            menuBlockId = new LongFilter();
        }
        return menuBlockId;
    }

    public void setMenuBlockId(LongFilter menuBlockId) {
        this.menuBlockId = menuBlockId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final MenuItemCriteria that = (MenuItemCriteria) o;
        return (
            Objects.equals(id, that.id) &&
            Objects.equals(code, that.code) &&
            Objects.equals(label, that.label) &&
            Objects.equals(order, that.order) &&
            Objects.equals(type, that.type) &&
            Objects.equals(createdDate, that.createdDate) &&
            Objects.equals(createdBy, that.createdBy) &&
            Objects.equals(dashboardPageId, that.dashboardPageId) &&
            Objects.equals(menuBlockId, that.menuBlockId)
        );
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, code, label, order, type, createdDate, createdBy, dashboardPageId, menuBlockId);
    }

    // prettier-ignore
    @Override
    public String toString() {
        return "MenuItemCriteria{" +
            (id != null ? "id=" + id + ", " : "") +
            (code != null ? "code=" + code + ", " : "") +
            (label != null ? "label=" + label + ", " : "") +
            (order != null ? "order=" + order + ", " : "") +
            (type != null ? "type=" + type + ", " : "") +
            (createdDate != null ? "createdDate=" + createdDate + ", " : "") +
            (createdBy != null ? "createdBy=" + createdBy + ", " : "") +
            (dashboardPageId != null ? "dashboardPageId=" + dashboardPageId + ", " : "") +
            (menuBlockId != null ? "menuBlockId=" + menuBlockId + ", " : "") +
            "}";
    }
}
