package it.eng.urbanite.dashboard.service.impl;

import java.util.List;
import java.util.Optional;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import it.eng.urbanite.dashboard.model.DashboardComponent;
import it.eng.urbanite.dashboard.repository.DashboardComponentRepository;
import it.eng.urbanite.dashboard.service.DashboardComponentService;
import it.eng.urbanite.dashboard.service.dto.DashboardComponentDTO;
import it.eng.urbanite.dashboard.service.mapper.DashboardComponentMapper;

/**
 * Service Implementation for managing {@link DashboardComponent}.
 */
@Service
@Transactional
public class DashboardComponentServiceImpl implements DashboardComponentService {
    private final Logger log = LoggerFactory.getLogger(DashboardComponentServiceImpl.class);
    private final DashboardComponentRepository dashboardComponentRepository;
    private final DashboardComponentMapper dashboardComponentMapper;

    public DashboardComponentServiceImpl(
        DashboardComponentRepository dashboardComponentRepository,
        DashboardComponentMapper dashboardComponentMapper
    ) {
        this.dashboardComponentRepository = dashboardComponentRepository;
        this.dashboardComponentMapper = dashboardComponentMapper;
    }

    @Override
    public DashboardComponentDTO save(DashboardComponentDTO dashboardComponentDTO) {
        log.debug("Request to save DashboardComponent : {}", dashboardComponentDTO);
        DashboardComponent dashboardComponent = dashboardComponentMapper.toEntity(dashboardComponentDTO);
        dashboardComponent = dashboardComponentRepository.save(dashboardComponent);
        return dashboardComponentMapper.toDto(dashboardComponent);
    }

    @Override
    @Transactional(readOnly = true)
    public Page<DashboardComponentDTO> findAll(Pageable pageable) {
        log.debug("Request to get all DashboardComponents");
        return dashboardComponentRepository.findAll(pageable).map(dashboardComponentMapper::toDto);
    }

    @Override
    @Transactional(readOnly = true)
    public Optional<DashboardComponentDTO> findOne(Long id) {
        log.debug("Request to get DashboardComponent : {}", id);
        return dashboardComponentRepository.findById(id).map(dashboardComponentMapper::toDto);
    }

    @Override
    public void delete(Long id) {
        log.debug("Request to delete DashboardComponent : {}", id);
        dashboardComponentRepository.deleteById(id);
    }

	@Override
	public List<DashboardComponentDTO> findAll() {
		log.debug("Request to get all DashboardComponents");
		List<DashboardComponent> l = dashboardComponentRepository.findAll();
		List<DashboardComponentDTO> r = dashboardComponentMapper.toDto(l);
        return r;
	}
}
