package it.eng.urbanite.dashboard.service.impl;

import java.util.List;
import java.util.Optional;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import it.eng.urbanite.dashboard.model.TargetAvailable;
import it.eng.urbanite.dashboard.model.enumeration.TargetType;
import it.eng.urbanite.dashboard.repository.TargetAvailableRepository;
import it.eng.urbanite.dashboard.service.TargetAvailableService;
import it.eng.urbanite.dashboard.service.dto.TargetAvailableDTO;
import it.eng.urbanite.dashboard.service.mapper.TargetAvailableMapper;

/**
 * Service Implementation for managing {@link TargetAvailable}.
 */
@Service
@Transactional
public class TargetAvailableServiceImpl implements TargetAvailableService {
    private final Logger log = LoggerFactory.getLogger(TargetAvailableServiceImpl.class);
    private final TargetAvailableRepository repository;
    private final TargetAvailableMapper mapper;

    public TargetAvailableServiceImpl(TargetAvailableRepository repository, TargetAvailableMapper mapper) {
        this.repository = repository;
        this.mapper = mapper;
    }

    @Override
    public TargetAvailableDTO save(TargetAvailableDTO targetDTO) {
        log.debug("Request to save TargetAvailable : {}", targetDTO);
        TargetAvailable target = mapper.toEntity(targetDTO);
        target = repository.save(target);
        return mapper.toDto(target);
    }

    @Override
    @Transactional(readOnly = true)
    public Page<TargetAvailableDTO> findAll(Pageable pageable) {
        log.debug("Request to get all TargetAvailables");
        return repository.findAll(pageable).map(mapper::toDto);
    }

    @Override
    @Transactional(readOnly = true)
    public Optional<TargetAvailableDTO> findOne(Long id) {
        log.debug("Request to get TargetAvailable : {}", id);
        return repository.findById(id).map(mapper::toDto);
    }

    @Override
    public void delete(Long id) {
        log.debug("Request to delete TargetAvailable : {}", id);
        repository.deleteById(id);
    }

	@Override
	public List<TargetAvailableDTO> findAll() {
		log.debug("Request to get all TargetAvailable");
        List<TargetAvailable> l = repository.findAll();
        List<TargetAvailableDTO> r = mapper.toDto(l);
        return r;
	}

	@Override
	public List<TargetAvailableDTO> findByType(TargetType type) {
		List<TargetAvailable> l = repository.findByType(type);
		List<TargetAvailableDTO> r = mapper.toDto(l);
        return r;
	}
}
