package it.eng.urbanite.dashboard.service.impl;

import java.util.List;
import java.util.Optional;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import it.eng.urbanite.dashboard.model.Target;
import it.eng.urbanite.dashboard.repository.TargetRepository;
import it.eng.urbanite.dashboard.service.TargetService;
import it.eng.urbanite.dashboard.service.dto.TargetDTO;
import it.eng.urbanite.dashboard.service.mapper.TargetMapper;

/**
 * Service Implementation for managing {@link Target}.
 */
@Service
@Transactional
public class TargetServiceImpl implements TargetService {
    private final Logger log = LoggerFactory.getLogger(TargetServiceImpl.class);
    private final TargetRepository targetRepository;
    private final TargetMapper targetMapper;

    public TargetServiceImpl(TargetRepository targetRepository, TargetMapper targetMapper) {
        this.targetRepository = targetRepository;
        this.targetMapper = targetMapper;
    }

    @Override
    public TargetDTO save(TargetDTO targetDTO) {
        log.debug("Request to save Target : {}", targetDTO);
        Target target = targetMapper.toEntity(targetDTO);
        target = targetRepository.save(target);
        return targetMapper.toDto(target);
    }

    @Override
    @Transactional(readOnly = true)
    public Page<TargetDTO> findAll(Pageable pageable) {
        log.debug("Request to get all Targets");
        return targetRepository.findAll(pageable).map(targetMapper::toDto);
    }

    @Override
    @Transactional(readOnly = true)
    public Optional<TargetDTO> findOne(Long id) {
        log.debug("Request to get Target : {}", id);
        return targetRepository.findById(id).map(targetMapper::toDto);
    }

    @Override
    public void delete(Long id) {
        log.debug("Request to delete Target : {}", id);
        targetRepository.deleteById(id);
    }

	@Override
	public List<TargetDTO> findAll() {
		log.debug("Request to get all Targets");
        List<Target> l = targetRepository.findAll();
        List<TargetDTO> r = targetMapper.toDto(l);
        return r;
	}
}
