package it.eng.urbanite.dashboard.web;

import java.net.URI;
import java.net.URISyntaxException;
import java.time.Instant;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import javax.validation.Valid;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import it.eng.urbanite.dashboard.config.Constants;
import it.eng.urbanite.dashboard.model.enumeration.CloningOpionType;
import it.eng.urbanite.dashboard.model.enumeration.MenuType;
import it.eng.urbanite.dashboard.repository.DashboardPageRepository;
import it.eng.urbanite.dashboard.security.SecurityUtils;
import it.eng.urbanite.dashboard.service.DashboardPageQueryService;
import it.eng.urbanite.dashboard.service.DashboardPageService;
import it.eng.urbanite.dashboard.service.UserService;
import it.eng.urbanite.dashboard.service.criteria.DashboardPageCriteria;
import it.eng.urbanite.dashboard.service.dto.DashboardPageCloningDTO;
import it.eng.urbanite.dashboard.service.dto.DashboardPageDTO;
import it.eng.urbanite.dashboard.utils.HeaderUtil;
import it.eng.urbanite.dashboard.web.error.BadRequestAlertException;
import tech.jhipster.service.filter.BooleanFilter;
import org.keycloak.representations.idm.UserRepresentation;

/**
 * REST controller for managing {@link it.eng.urbanite.dashboard.domain.DashboardPage}.
 */
@RestController
@CrossOrigin
@RequestMapping("/public")
public class PublicDashboardPageResource {
    private final Logger log = LoggerFactory.getLogger(DashboardPageResource.class);
    private static final String ENTITY_NAME = "dashboardPage";

    private String applicationName = Constants.APP_NAME;

    private final DashboardPageService dashboardPageService;
    private final DashboardPageRepository dashboardPageRepository;
    private final DashboardPageQueryService dashboardPageQueryService;
    private final UserService userService;
    
    public PublicDashboardPageResource(
        DashboardPageService dashboardPageService,
        DashboardPageRepository dashboardPageRepository,
        DashboardPageQueryService dashboardPageQueryService,
        UserService userService
    ) {
        this.dashboardPageService = dashboardPageService;
        this.dashboardPageRepository = dashboardPageRepository;
        this.dashboardPageQueryService = dashboardPageQueryService;
        this.userService = userService;
    }
    

    @GetMapping("/dashboards")
    public ResponseEntity<List<DashboardPageDTO>> getAllPublicDashboardPages() {
        log.debug("REST request to get DashboardPages");
        List<DashboardPageDTO> list = dashboardPageService.findAll()
        .stream()
        .filter(d -> d.getType().equals(MenuType.PUBLIC))
        .collect(Collectors.toList());
        return ResponseEntity.ok().body(list);
    }
}
